/*
*******************************************************************************
**
**  This device driver was created by Applilet for the 78K0S/KB1+, 78K0S/KA1+,
**  78K0S/KY1+ 8-Bit Single-Chip Microcontrollers
**
**  Copyright(C) NEC Electronics Corporation 2002-2004
**  All rights reserved by NEC Electronics Corporation.
**
**  This program should be used on your own responsibility.
**  NEC Electronics Corporation assumes no responsibility for any losses
**  incurred by customers or third parties arising from the use of this file.
**
**  Filename :	timer.c
**  Abstract :	This file implements device driver for the timer module.
**  APIlib :	NEC78K0SKX1H.lib E1.46a [13 May 2005]
**
**  Device :	uPD78F9222
**
**  Compiler :	NEC/CC78K0
**
*******************************************************************************
*/

/*
*******************************************************************************
**  Include files
*******************************************************************************
*/
#include "macrodriver.h"
#include "timer.h"


/*
*******************************************************************************
**  MacroDefine
*******************************************************************************
*/

/* TM00 pulse width measure */

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function initializes TM00_module.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM00_Init( void )
{
	TMC00 = 0x00;
	PRM00 |= TM_TM00_CLOCK;		/* internal count clock */
	ClrIORBit(IF0, 0x20);		/* set INTTM000 */
	ClrIORBit(CRC00, 0x01);		/* TM00 interval */
	CR000 = TM_TM00_INTERVALVALUE;
	CR010 = 0xffff;
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function can start the TM00 counter.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM00_Start( void )
{
	TMC00 = 0x0c;			/* interval timer start */
	ClrIORBit(MK0, 0x20);		/* INTTM000 enable */
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function can stop the TM00 counter and clear the count register.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM00_Stop( void )
{
	TMC00 = 0x0;
	SetIORBit(MK0, 0x20);		/* INTTM000 disable */
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function can change TM00 condition.
**	
**  Parameters:
**	*array_reg :	value(s) to set condition
**	array_num :	value number
**
**  Returns:
**	MD_OK
**	MD_ERROR
**
**-----------------------------------------------------------------------------
*/
MD_STATUS TM00_ChangeTimerCondition( USHORT *array_reg, USHORT array_num )
{
	switch ( array_num ){
		case 2:
			CR010 = *( array_reg + 1 );
		case 1:
			CR000 = *( array_reg + 0 );
			break;
		default:
			return MD_ERROR;
	}
	return MD_OK;
}
